@@ -15,17 +15,22 @@ use hal::power::{LowPowerMode, PowerMode};
 use hal::prelude::*;
 use hal::rcc::{self, Prescaler};
 use hal::stm32;
-use rtic::app;
 
-#[app(device = hal::stm32, peripherals = true)]
-const APP: () = {
-    struct Resources {
+#[rtic::app(device = hal::stm32, peripherals = true)]
+mod app {
+    use super::*;
+
+    #[shared]
+    struct Shared {}
+
+    #[local]
+    struct Local {
         exti: stm32::EXTI,
         led: PA5<Output<PushPull>>,
     }
 
     #[init]
-    fn init(mut ctx: init::Context) -> init::LateResources {
+    fn init(ctx: init::Context) -> (Shared, Local, init::Monotonics) {
         let mut rcc = ctx.device.RCC.freeze(rcc::Config::hsi(Prescaler::Div16));
         let mut exti = ctx.device.EXTI;
 
@@ -36,18 +41,26 @@ const APP: () = {
         let button = gpioc.pc13.listen(SignalEdge::Falling, &mut exti);
 
         let mut power = ctx.device.PWR.constrain(&mut rcc);
-        power.set_mode(PowerMode::LowPower(LowPowerMode::StopMode2));
+        power.set_mode(PowerMode::UltraLowPower(LowPowerMode::StopMode2));
 
         if button.is_high().unwrap() {
-            ctx.core.SCB.set_sleepdeep();
+            let mut scb = ctx.core.SCB;
+            scb.set_sleepdeep();
         }
 
-        init::LateResources { exti, led }
+        (Shared {}, Local { exti, led }, init::Monotonics())
     }
 
-    #[task(binds = EXTI4_15, resources = [exti, led])]
+    #[task(binds = EXTI4_15, local = [exti, led])]
     fn button_click(ctx: button_click::Context) {
-        ctx.resources.led.toggle().unwrap();
-        ctx.resources.exti.unpend(Event::GPIO13);
+        ctx.local.led.toggle().unwrap();
+        ctx.local.exti.unpend(Event::GPIO13);
     }
-};
+
+    #[idle]
+    fn idle(_: idle::Context) -> ! {
+        loop {
+            cortex_m::asm::wfi();
+        }
+    }
+}
